@@ -37,3 +37,5 @@ class Model:
 class ModelType(Enum):
     ACOUSTIC = 'AM'
     LINGUISTIC = 'LM'
+    PUNCTUATION_CAPITALIZATION = 'PUNCTCAP'
+    ENTITY_RECOGNITION = 'NER'
