@@ -7,12 +7,16 @@ from vatis.asr_commons.domain.transcriber import NdArrayDataPacket
 from vatis.asr_commons.domain.transcriber import LogitsDataPacket
 from vatis.asr_commons.domain.transcriber import SpacedLogitsDataPacket
 
+from vatis.asr_commons.domain.exception import AudioFormatError
+
 __all__ = (
+    'DataPacket',
     'ByteDataPacket',
     'TranscriptionPacket',
     'Word',
     'TimestampedTranscriptionPacket',
     'NdArrayDataPacket',
     'LogitsDataPacket',
-    'SpacedLogitsDataPacket'
+    'SpacedLogitsDataPacket',
+    'AudioFormatError'
 )
