@@ -22,24 +22,39 @@ class DataPacket:
     def set_header(self, name, value):
         self.headers[name] = value
 
+    def __str__(self):
+        return f'"headers": {str(self.headers)}'
+
+    def __repr__(self):
+        return self.__str__()
+
 
 class StringPacket(DataPacket):
     def __init__(self, data: str, headers=None):
         super().__init__(headers)
         self.data = data
 
+    def __str__(self):
+        return f'{{"data": {self.data}, {super().__str__()}}}'
+
 
 class ByteDataPacket(DataPacket):
     def __init__(self, data: bytes, headers=None):
         super().__init__(headers)
         self.data = data
 
+    def __str__(self):
+        return f'{{"data": {hash(self.data)}, {super().__str__()}}}'
+
 
 class TranscriptionPacket(DataPacket):
     def __init__(self, transcript: str, headers=None):
         super().__init__(headers)
         self.transcript = transcript
 
+    def __str__(self):
+        return f'{{"transcript": {hash(self.transcript)}, {super().__str__()}}}'
+
 
 class Word:
     def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[int] = None,
@@ -50,6 +65,20 @@ class Word:
         self.speaker: int = speaker
         self.confidence: float = confidence
 
+    def __str__(self):
+        return f'''
+        {{
+            "word": {self.word},
+            "start_time": {self.start_time},
+            "end_time": {self.end_time},
+            "speaker": {self.speaker},
+            "confidence": {self.confidence}
+        }}
+        '''
+
+    def __repr__(self):
+        return self.__str__()
+
 
 class TimestampedTranscriptionPacket(TranscriptionPacket):
     """
@@ -59,27 +88,39 @@ class TimestampedTranscriptionPacket(TranscriptionPacket):
      - words: list of transcribed words
      - headers: headers of the packet
     """
+
     def __init__(self, words: List[Word], headers=None, transcript=None):
         transcript = transcript if transcript is not None else ' '.join([word.word for word in words])
         super().__init__(transcript, headers)
 
         self.words = words
 
+    def __str__(self):
+        return f'{{"words": {str(self.words)}, {super().__str__()}}}'
+
 
 class NdArrayDataPacket(DataPacket):
     def __init__(self, data: np.ndarray, headers=None):
         super().__init__(headers)
         self.data: np.ndarray = data
 
+    def __str__(self):
+        return f'{{"data": {hash(self.data.tobytes())}, {super().__str__()}}}'
+
 
 class LogitsDataPacket(NdArrayDataPacket):
     def __init__(self, data: np.ndarray, timestep_duration: float, headers=None):
         super().__init__(data, headers)
         self.timestep_duration = timestep_duration
 
+    def __str__(self):
+        return f'{{"timestep_duration": {self.timestep_duration}, {super().__str__()}}}'
+
 
 class SpacedLogitsDataPacket(LogitsDataPacket):
     def __init__(self, data: np.ndarray, timestep_duration: float, spaces: List[Tuple[int, int]], headers=None):
         super().__init__(data, timestep_duration, headers)
         self.spaces = spaces
 
+    def __str__(self):
+        return f'{{"spaces": {str(self.spaces)}, {super().__str__()}}}'
